var unselectedColor = "#fff";
var highlightedColor = "#90c7eb";

var highlightedDiv = null;
var optionsId = -1;

var filterString = "";
var filterVersion = 0;
var finishedLoading = false;

function ReplaceAll(content) {
    filterVersion = content.FilterVersion;
    ReplaceContacts(content);
    ReplaceFavorites(content);
    ReplaceRecents(content);
    ReplaceNoMatches(content);
}

function ReplaceContacts(content) {
  ClearContacts();
  AppendContacts(content);
}

function ClearContacts(content) {
    if (content != null)
      filterVersion = content.FilterVersion;
    
    var contactsListDiv = document.getElementById("contacts-list");
    for(var child; child = contactsListDiv.firstChild;) {
        contactsListDiv.removeChild(child);
    }
}
   
function FinishLoading() {
   finishedLoading = true;
}

function AppendContacts(content) {
    var contactsListDiv = document.getElementById("contacts-list");
    var version = content.FilterVersion;

    if (filterVersion != version)
            return;
    var nodes = document.createElement("div");
    nodes.innerHTML = content.Contacts;
    for (i = 0; i < nodes.childNodes.length; i++) {
      contactsListDiv.appendChild (nodes.childNodes[i]);
    }

    if (!content.Contacts || !content.Contacts.length) {
        document.getElementById("contacts-set").style.display = "none";
    } else {
        document.getElementById("contacts-set").style.display = "block";
    }
}

function ReplaceFavorites(content) {
    var favoritesListDiv = document.getElementById("favorites-list");
    for(var child; child = favoritesListDiv.firstChild;) {
        favoritesListDiv.removeChild(child);
    }
    favoritesListDiv.innerHTML = content.Favorites;
    if(!content.Favorites || !content.Favorites.length) {
        document.getElementById("favorites-set").style.display = "none";
    }
    else {
        document.getElementById("favorites-set").style.display = "block";
    }
}

function ReplaceRecents(content) {
    var groupsListDiv = document.getElementById("groups-list");
    for(var child; child = groupsListDiv.firstChild;) {
        groupsListDiv.removeChild(child);
    }
    groupsListDiv.innerHTML = content.Groups;
    if(!content.Groups || !content.Groups.length) {
        document.getElementById("groups-set").style.display = "none";
    }
    else {
        document.getElementById("groups-set").style.display = "block";
    }
}

function ReplaceNoMatches(content) {
    var noMatchesListDiv = document.getElementById("no-matches-list");
    for(var child; child = noMatchesListDiv.firstChild;) {
        noMatchesListDiv.removeChild(child);
    }
    noMatchesListDiv.innerHTML = content.NoMatches;
    if (!content.NoMatches || !content.NoMatches.length) {
        document.getElementById("no-matches-set").style.display = "none";
    }
    else {
        document.getElementById("no-matches-set").style.display = "block";
    }
}

function ReplaceGAL(content) {
    var galListDiv = document.getElementById("gal-list");
    for(var child; child = galListDiv.firstChild;) {
        galListDiv.removeChild(child);
    }
    galListDiv.innerHTML = content;

}

function ContactSelected(contactId) {
    ddx.send("ContactSelected", contactId);
}

function GroupSelected(groupId) {
    ddx.send("GroupSelected", groupId);
}

function AddEmailContact(name, email) {
    ddx.send("AddEmailContact", JSON.stringify({Name: name, Principal: email}));
}

function AddPhoneContact(name, phone) {
    ddx.send("AddPhoneContact", JSON.stringify({Name: name, Principal: phone}));
}

 

function searchContactsDidChange() {
    document.getElementById("body").scrollTop = 0;
    filterString = document.getElementById("searchContactsField").value.toLowerCase();
    ddx.send("Filter", filterString);
}

function SlidingStateChanged() {
    //TODO: cancel any touch started stuff
}


var busy = document.getElementById("busy");
var error = document.getElementById("error");
function PostLayout() {
  
    busy = document.getElementById("busy");
    error = document.getElementById("error");
    
    document.getElementById("body").ontouchstart = function() {
        document.activeElement.blur();
        ddx.send("HideKeyboard");
    };
    AdjustSize();
}

function Busy() {
    busy.style.display = "block";
    error.style.display = "none";
}
function Error(raw) {
    busy.style.display = "none";
    error.style.display = "block";
}
function Done() {
    busy.style.display = "none";
    error.style.display = "none";
}

hammer.on("touch", function(event) {

    var touchable = getTouchable(event.target);
    if (touchable == null)
        return true;
    highlightedDiv = touchable;
    highlightedDiv.style.background = highlightedColor;

});
hammer.on("release", function (event) {
    if(highlightedDiv != null) {
        highlightedDiv.style.background = unselectedColor;
        highlightedDiv = null;
    }
});

hammer.on("tap", function (event) {
    var touchable = getTouchable(event.target);
    if (touchable == null)
        return true;
    return selectedItem(touchable);
});
  

function GroupClicked(id) {
  // hammer is faster, but fails if we are still manipulating the dom.
  if (!finishedLoading) {
    GroupSelected(id);
  }
}

var lastSelection = 0;

function selectedItem(touchable) {
    var now = new Date().getTime();
    if (now - lastSelection < 1200)
      return;

    lastSelection = now;
    var parts = touchable.getAttribute("data-touchable").split(':');
    if (parts[0] == "contact") {
        if(parts[1] === "email") {
            var name = touchable.getAttribute("data-contact-name");
            var principal = touchable.getAttribute("data-contact-principal");
            AddEmailContact(name, principal);
        }
        else if(parts[1] === "phone") {
            var name = touchable.getAttribute("data-contact-name");
            var principal = touchable.getAttribute("data-contact-principal");
            AddPhoneContact(name, principal);
        }
        else {
            ContactSelected(parts[1]);
        }
        return false;
    }
    if (parts[0] == "group") {
        GroupSelected(parts[1]);

        return false;
    }

    return true;
}

  